# Shooker
Tool for C-code injections in already compiled bins.

## Usage
Write hook config as described in the [instruction](docs/hooks%20xml.md).

```shooker --xml config.xml target_dir/ output_dir/```
